UnionCheckpointSchedule
=======================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: UnionCheckpointSchedule
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~UnionCheckpointSchedule.bases_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~UnionCheckpointSchedule.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: bases_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: __call__
